# flake8-override

[![Build Status](https://github.com/blablatdinov/flake8-override/workflows/test/badge.svg?branch=master&event=push)](https://github.com/blablatdinov/flake8-override/actions?query=workflow%3Atest)
[![codecov](https://codecov.io/gh/blablatdinov/flake8-override/branch/master/graph/badge.svg)](https://codecov.io/gh/blablatdinov/flake8-override)
[![Python Version](https://img.shields.io/pypi/pyversions/flake8-override.svg)](https://pypi.org/project/flake8-override/)
[![wemake-python-styleguide](https://img.shields.io/badge/style-wemake-000000.svg)](https://github.com/wemake-services/wemake-python-styleguide)

This is how python package should look like!

## Features

- Fully typed with annotations and checked with mypy, [PEP561 compatible](https://www.python.org/dev/peps/pep-0561/)
- Add yours!

## Installation

```bash
pip install flake8-override
```

## Example

Showcase how your project can be used:

```python
from flake8_override.example import some_function

print(some_function(3, 4))
# => 7
```

## License

[MIT](https://github.com/blablatdinov/flake8-override/blob/master/LICENSE)

## Credits

This project was generated with [`wemake-python-package`](https://github.com/wemake-services/wemake-python-package). Current template version is: [864a62ecb432655249d071e263ac51f053448659](https://github.com/wemake-services/wemake-python-package/tree/864a62ecb432655249d071e263ac51f053448659). See what is [updated](https://github.com/wemake-services/wemake-python-package/compare/864a62ecb432655249d071e263ac51f053448659...master) since then.
